==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Top/language/lang-german.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/


define("_CATEGORY","Bereich");

define("_LVOTES","Stimmen");
define("_HITS","Hits");
define("_TOPWELCOME","Willkommen bei den TOP 10 von");
define("_READSTORIES","am meisten gelesene Artikel");
define("_COMMENTEDSTORIES","am meisten kommentierte Artikel");
define("_ACTIVECAT","aktivste Bereiche");
define("_READSECTION","meistgelesene Artikel in den Bereichen");
define("_NEWSSUBMITTERS","aktivste Nachrichtenschreiber");
define("_NEWSSENT","Gesendete Nachrichten");
define("_VOTEDPOLLS","aktivste Umfragen");
define("_MOSTACTIVEAUTHORS","aktivste Autoren");
define("_NEWSPUBLISHED","Nachrichten geschrieben");
define("_READREVIEWS","am meisten gelesene Testberichte");
define("_DOWNLOADEDFILES","am meisten gezogene Downloads");
define("_MOSTREADPAGES","meist gelesene Seiten");
define("_MOSTVOTEDSTORIES","most voted stories");
define("_POINTS","points");
define("_BESTRATEDSTORIES","best rated stories (based on 5 maximun points)");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Top/language/lang-german.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/


define("_CATEGORY","Bereich");

define("_LVOTES","Stimmen");
define("_HITS","Hits");
define("_TOPWELCOME","Willkommen bei den TOP 10 von");
define("_READSTORIES","am meisten gelesene Artikel");
define("_COMMENTEDSTORIES","am meisten kommentierte Artikel");
define("_ACTIVECAT","aktivste Bereiche");
define("_READSECTION","meistgelesene Artikel in den Bereichen");
define("_NEWSSUBMITTERS","aktivste Nachrichtenschreiber");
define("_NEWSSENT","Gesendete Nachrichten");
define("_VOTEDPOLLS","aktivste Umfragen");
define("_MOSTACTIVEAUTHORS","aktivste Autoren");
define("_NEWSPUBLISHED","Nachrichten geschrieben");
define("_READREVIEWS","am meisten gelesene Testberichte");
define("_DOWNLOADEDFILES","am meisten gezogene Downloads");
define("_MOSTREADPAGES","meist gelesene Seiten");
define("_MOSTVOTEDSTORIES","most voted stories");
define("_POINTS","points");
define("_BESTRATEDSTORIES","best rated stories (based on 5 maximun points)");

?>
